@@ -129,6 +129,8 @@ graph.adjacency.dense <- function(adjmatrix, mode=c("directed", "undirected", "m
                  "lower"=3,
                  "min"=4,
                  "plus"=5)
+
+  mode(adjmatrix) <- "double"
   
   if (!is.null(weighted)) {
     if (is.logical(weighted) && weighted) {
@@ -142,8 +144,6 @@ graph.adjacency.dense <- function(adjmatrix, mode=c("directed", "undirected", "m
       stop("not a square matrix")
     }
 
-    mode(adjmatrix) <- "numeric"
-    
     on.exit( .Call("R_igraph_finalizer", PACKAGE="igraph") )
     res <- .Call("R_igraph_weighted_adjacency", adjmatrix,
                  as.numeric(mode), weighted, diag,
@@ -171,8 +171,6 @@ graph.adjacency.sparse <- function(adjmatrix, mode=c("directed", "undirected", "
 
   mode <- igraph.match.arg(mode)
 
-  require(Matrix)
-  
   if (!is.null(weighted)) {
     if (is.logical(weighted) && weighted) {
       weighted <- "weight"
@@ -181,7 +179,9 @@ graph.adjacency.sparse <- function(adjmatrix, mode=c("directed", "undirected", "
       stop("invalid value supplied for `weighted' argument, please see docs.")
     }
   }
-  
+
+  mysummary <- Matrix::summary
+
   if (nrow(adjmatrix) != ncol(adjmatrix)) {
     stop("not a square matrix")
   }
@@ -197,23 +197,22 @@ graph.adjacency.sparse <- function(adjmatrix, mode=c("directed", "undirected", "
   
   if (mode == "directed") {
     ## DIRECTED
-    el <- selectMethod("summary", "sparseMatrix")(adjmatrix)
+    el <- mysummary(adjmatrix)
     if (!diag) { el <- el[ el[,1] != el[,2], ] }      
   } else if (mode == "undirected") {
     ## UNDIRECTED, must be symmetric if weighted
-    if (!is.null(weighted) &&
-        !selectMethod("isSymmetric", "sparseMatrix")(adjmatrix)) {
+    if (!is.null(weighted) && !Matrix::isSymmetric(adjmatrix)) {
       stop("Please supply a symmetric matrix if you want to create a weighted graph with mode=UNDIRECTED.")
     }
     if (diag) {
-      adjmatrix <- tril(adjmatrix)
+      adjmatrix <- Matrix::tril(adjmatrix)
     } else {
-      adjmatrix <- tril(adjmatrix, -1)
+      adjmatrix <- Matrix::tril(adjmatrix, -1)
     }      
-    el <- selectMethod("summary", "sparseMatrix")(adjmatrix)
+    el <- mysummary(adjmatrix)
   } else if (mode=="max") {
     ## MAXIMUM
-    el <- selectMethod("summary", "sparseMatrix")(adjmatrix)
+    el <- mysummary(adjmatrix)
     rm(adjmatrix)
     if (!diag) { el <- el[ el[,1] != el[,2], ] }
     el <- el[ el[,3] != 0, ]
@@ -221,44 +220,45 @@ graph.adjacency.sparse <- function(adjmatrix, mode=c("directed", "undirected", "
     el <- el[,1:2]
     el <- cbind( pmin(el[,1],el[,2]), pmax(el[,1], el[,2]) )
     o <- order(el[,1], el[,2])
-    el <- el[o,]
+    el <- el[o,,drop=FALSE]
     w <- w[o]
-    dd <- el[2:nrow(el),1] == el[1:(nrow(el)-1),1] &
-          el[2:nrow(el),2] == el[1:(nrow(el)-1),2]
-    dd <- which(dd)
-    if (length(dd)>0) {
-      mw <- pmax(w[dd], w[dd+1])
-      w[dd] <- mw
-      w[dd+1] <- mw
-      el <- el[-dd,]
-      w <- w[-dd]
+    if (nrow(el) > 1) {
+      dd <- el[2:nrow(el),1] == el[1:(nrow(el)-1),1] &
+        el[2:nrow(el),2] == el[1:(nrow(el)-1),2]
+      dd <- which(dd)
+      if (length(dd)>0) {
+        mw <- pmax(w[dd], w[dd+1])
+        w[dd] <- mw
+        w[dd+1] <- mw
+        el <- el[-dd,,drop=FALSE]
+        w <- w[-dd]
+      }
     }
     el <- cbind(el, w)
-    rm(w,dd)
   } else if (mode=="upper") {
     ## UPPER
     if (diag) {
-      adjmatrix <- triu(adjmatrix)
+      adjmatrix <- Matrix::triu(adjmatrix)
     } else {
-      adjmatrix <- triu(adjmatrix, 1)
+      adjmatrix <- Matrix::triu(adjmatrix, 1)
     }
-    el <- selectMethod("summary", "sparseMatrix")(adjmatrix)
+    el <- mysummary(adjmatrix)
     rm(adjmatrix)
     if (!diag) { el <- el[ el[,1] != el[,2], ] }      
   } else if (mode=="lower") {
     ## LOWER
     if (diag) {
-      adjmatrix <- tril(adjmatrix)
+      adjmatrix <- Matrix::tril(adjmatrix)
     } else {
-      adjmatrix <- tril(adjmatrix, -1)
+      adjmatrix <- Matrix::tril(adjmatrix, -1)
     }
-    el <- selectMethod("summary", "sparseMatrix")(adjmatrix)
+    el <- mysummary(adjmatrix)
     rm(adjmatrix)
     if (!diag) { el <- el[ el[,1] != el[,2], ] }      
   } else if (mode=="min") {
     ## MINIMUM
     adjmatrix <- sign(adjmatrix) * sign(Matrix::t(adjmatrix)) * adjmatrix
-    el <- selectMethod("summary", "sparseMatrix")(adjmatrix)
+    el <- mysummary(adjmatrix)
     if (!diag) { el <- el[ el[,1] != el[,2], ] }
     el <- el[ el[,3] != 0, ]
     w <- el[,3]
@@ -267,27 +267,28 @@ graph.adjacency.sparse <- function(adjmatrix, mode=c("directed", "undirected", "
     o <- order(el[,1], el[,2])
     el <- el[o,]
     w <- w[o]
-    dd <- el[2:nrow(el),1] == el[1:(nrow(el)-1),1] &
-          el[2:nrow(el),2] == el[1:(nrow(el)-1),2]
-    dd <- which(dd)
-    if (length(dd)>0) {
-      mw <- pmin(w[dd], w[dd+1])
-      w[dd] <- mw
-      w[dd+1] <- mw
-      el <- el[-dd,]
-      w <- w[-dd]
+    if (nrow(el) > 1) {
+      dd <- el[2:nrow(el),1] == el[1:(nrow(el)-1),1] &
+        el[2:nrow(el),2] == el[1:(nrow(el)-1),2]
+      dd <- which(dd)
+      if (length(dd)>0) {
+        mw <- pmin(w[dd], w[dd+1])
+        w[dd] <- mw
+        w[dd+1] <- mw
+        el <- el[-dd,]
+        w <- w[-dd]
+      }
     }
     el <- cbind(el, w)
-    rm(w,dd)
   } else if (mode=="plus") {
     ## PLUS
     adjmatrix <- adjmatrix + Matrix::t(adjmatrix)
     if (diag) {
-      adjmatrix <- tril(adjmatrix)
+      adjmatrix <- Matrix::tril(adjmatrix)
     } else {
-      adjmatrix <- tril(adjmatrix, -1)
+      adjmatrix <- Matrix::tril(adjmatrix, -1)
     }
-    el <- selectMethod("summary", "sparseMatrix")(adjmatrix)
+    el <- mysummary(adjmatrix)
     if (diag) {
       loop <- el[,1] == el[,2]
       el[loop,3] <- el[loop,3] / 2
@@ -518,16 +519,13 @@ graph.atlas <- function(n) {
 
 graph.data.frame <- function(d, directed=TRUE, vertices=NULL) {
 
+  d <- as.data.frame(d)
+  if (!is.null(vertices)) { vertices <- as.data.frame(vertices) }
+  
   if (ncol(d) < 2) {
     stop("the data frame should contain at least two columns")
   }
 
-  ## This is to avoid scientific notation in vertex names, if they
-  ## happen to be numbers
-  scipen <- getOption("scipen")
-  options("scipen"=999)
-  on.exit(options(scipen=scipen))
-  
   ## Handle if some elements are 'NA'
   if (any(is.na(d[,1:2]))) {
     warning("In `d' `NA' elements were replaced with string \"NA\"")
@@ -724,7 +722,7 @@ graph.incidence.sparse <- function(incidence, directed, mode, multiple,
                                    weighted) {
   n1 <- nrow(incidence)
   n2 <- ncol(incidence)
-  el <- selectMethod("summary", signature=c(object="sparseMatrix"))(incidence)
+  el <- Matrix::summary(incidence)
   ## el <- summary(incidence)
   el[,2] <- el[,2] + n1
 
